
.. image:: https://raw.github.com/pyrf/pyrf/master/docs/pyrf_logo.png
   :alt: PyRF logo

Hardware Support
----------------

This library currently supports development for the
`ThinkRF WSA4000 and WSA5000`_ platforms.

.. _ThinkRF WSA4000 and WSA5000: http://www.thinkrf.com/

Links
-----

* `Official github page <https://github.com/pyrf/pyrf>`_
* `Documentation for this API <http://www.pyrf.org>`_
* `WSA4000/WSA5000 Documentation <http://www.thinkrf.com/resources>`_

Spectrum Analyzer GUI
---------------------

.. image:: https://raw.github.com/pyrf/pyrf/master/docs/speca-gui.png
   :alt: speca-gui screen shot

.. image:: https://raw.github.com/pyrf/pyrf/master/docs/speca-gui-2.png
   :alt: speca-gui screen shot

